# Importing and Updating Fact Sheets
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/importing-and-updating-fact-sheets#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/importing-and-updating-fact-sheets#prerequisites)
  * [Step 1: Import Fact Sheets with Basic Information](https://help.sap.com/docs/leanix/ea/importing-and-updating-fact-sheets#step-1:-import-fact-sheets-with-basic-information)
  * [Step 2: Update Fact Sheets with Business Criticality Values](https://help.sap.com/docs/leanix/ea/importing-and-updating-fact-sheets#step-2:-update-fact-sheets-with-business-criticality-values)
  * [Summary](https://help.sap.com/docs/leanix/ea/importing-and-updating-fact-sheets#summary)


Learn how to import and update application fact sheets using the inboundFactSheet processor of the Integration API.
